@@ -1,17 +1,21 @@
-#' Nearest species sightings
+#' Recent nearby observations of a species
 #'
 #' Returns the most recent and nearest reported sighting information
 #' with observations of a species.
 #'
 #' @export
 #' 
-#' @param species (required) Scientific name of the species of interest (not case
-#'    sensitive). See eBird taxonomy for more information:
+#' @param speciesCode (required) Species code of the species of interest. 
+#'    Scientific names can be specified if wrapped around the 
+#'    \code{\link{species_code}} function. Defaults to NULL, so sightings for all species are returned.
+#'    See eBird taxonomy for more information:
 #'    http://ebird.org/content/ebird/about/ebird-taxonomy
 #' @param lat Decimal latitude. value between -90.00 and 90.00, up to two
-#'    decimal places of precision. Defaults to latitude basd on IP.
+#'    decimal places of precision. Defaults to latitude based on IP.
 #' @param lng Decimal longitude. value between -180.00 and 180.00, up to
-#'    two decimal places of precision. Defaults to longitude basd on IP.
+#'    two decimal places of precision. Defaults to longitude based on IP.
+#' @param dist Distance defining radius of interest from given lat/lng in
+#'    kilometers (between 0 and 50, defaults to 25)
 #' @param back Number of days back to look for observations (between
 #'    1 and 30, defaults to 14).
 #' @param max Maximum number of result rows to return in this request
@@ -26,6 +30,9 @@
 #' @param sleep Time (in seconds) before function sends API call (defaults to
 #'    zero. Set to higher number if you are using this function in a loop with
 #'    many API calls).
+#' @param key ebird API key. You can obtain one from https://ebird.org/api/keygen.
+#'    We strongly recommend storing it in your \code{.Renviron} file as an 
+#'    environment variable called \code{EBIRD_KEY}.
 #' @param ... Curl options passed on to \code{\link[httr]{GET}}
 #' @return A data.frame containing the collected information:
 #' @return "comName": species common name
@@ -43,15 +50,17 @@
 #'    automatic filters or a regional viewer, FALSE otherwise
 #' @return "sciName" species' scientific name
 #' 
-#' @author Rafael Maia \email{rm72@@zips.uakron.edu}
+#' @author Rafael Maia \email{rm72@@zips.uakron.edu},
+#'    Sebastian Pardo \email{sebpardo@@gmail.com}
 #' @references \url{http://ebird.org/}
 #' @examples \dontrun{
-#' nearestobs('branta canadensis', 42, -76)
-#' nearestobs('branta canadensis', 42, -76, max=10, provisional=TRUE, hotspot=TRUE)
+#' nearestobs('cangoo', 42, -76) # Canada Goose
+#' nearestobs(species_code('branta canadensis'), 42, -76) # Same as above
+#' nearestobs(species_code('branta canadensis'), 42, -76, max=10, provisional=TRUE, hotspot=TRUE)
 #' }
 
-nearestobs <-  function(species, lat = NULL, lng = NULL, back = NULL, max = NULL, locale = NULL, 
-  provisional = FALSE, hotspot = FALSE, sleep = 0, ...)
+nearestobs <-  function(speciesCode, lat = NULL, lng = NULL, dist = NULL, back = NULL, max = NULL, locale = NULL, 
+  provisional = FALSE, hotspot = FALSE, sleep = 0, key = NULL, ...)
 {
   Sys.sleep(sleep)
 
@@ -75,14 +84,13 @@ nearestobs <-  function(species, lat = NULL, lng = NULL, back = NULL, max = NULL
   }
 
   args <- ebird_compact(list(
-    fmt='json', sci=species,
-    lat=round(geoloc[1],2), lng=round(geoloc[2],2),
-    back=back, maxResults=max,
-    locale=locale
+    lat = round(geoloc[1], 2), lng = round(geoloc[2], 2),
+    dist = dist, back = back, maxResults = max,
+    sppLocale = locale
   ))
 
   if(provisional) args$includeProvisional <- 'true'
   if(hotspot) args$hotspot <- 'true'
 
-  ebird_GET(paste0(ebase(), 'data/nearest/geo_spp/recent'), args, ...)
+  ebird_GET(paste0(ebase(), 'data/obs/geo/recent/', speciesCode), args, key = key, ...)
 }
