@@ -12,7 +12,7 @@ test_that("ebirdtaxonomy works correctly", {
   expect_is(out2, "tbl_df")
   
   expect_is(out$comName, "character")
-  expect_is(out$taxonID, "character")
+  expect_is(out$taxonOrder, "numeric")
 })
 
 test_that("ebirdtaxonomy fails correctly", {
@@ -24,3 +24,9 @@ test_that("ebirdtaxonomy fails correctly", {
   
   expect_error(ebirdtaxonomy("spuh", config=timeout(0.02)))
 })
+
+test_that_without_key("ebirdtaxonomy works without an API key", {
+  tax <- ebirdtaxonomy()
+  expect_is(tax, "data.frame")
+  expect_equal(ncol(tax), 14L)
+})
